@@ -15,6 +15,9 @@ function(FILEPATH,SPARTAN_PARAMETER_FILE,PARAMETERS,NUMSAMPLES,NUMRUNSPERSAMPLE,
 			# READ IN THE SPARTAN PARAMETER FILE
 			LHCTABLE<-read.csv(paste(FILEPATH,"/",SPARTAN_PARAMETER_FILE,sep=""),header=TRUE)
 
+			# Check the Measures and Parameters for Spaces - R will have replaced these with a dot
+			MEASURES<-table_header_check(MEASURES)
+			
 			# NOW ALL THE MEDIANS ARE HELD TOGETHER, ACCOMPANIED BY THEIR SIMULATION PARAMETERS BEING ANALYSED
 			ALL_SIM_MEDIAN_RESULTS<-NULL
 		
